@@ -124,7 +124,7 @@ def execution_loop(tasks, options, tasks_executed, tasks_loaded):
     logging.info('Execute start (%s tasks)' % len(tasks))
     while tasks:
         upnext = [] # tasks that can be run
-        for i in range(options.execute_nr_wait_cycles):
+        for i in range(int(options.execute_nr_wait_cycles)):
             max_cannot_run = min(len(tasks), 128)
             for i in range(max_cannot_run):
                 # The argument for this is the following:
@@ -147,7 +147,7 @@ def execution_loop(tasks, options, tasks_executed, tasks_loaded):
             if upnext:
                 break
             logging.info('waiting %s secs for an open task...' % options.execute_wait_cycle_time_secs)
-            sleep(options.execute_wait_cycle_time_secs)
+            sleep(int(options.execute_wait_cycle_time_secs))
         if not upnext:
             logging.info('No tasks can be run!')
             break
@@ -175,14 +175,23 @@ def execution_loop(tasks, options, tasks_executed, tasks_loaded):
                     import sys
                     _,_, tb = sys.exc_info()
 
+                    # The code below is a complex attempt to load IPython
+                    # debugger which works with multiple versions of IPython.
+                    #
+                    # Unfortunately, their API kept changing prior to the 1.0.
                     try:
                         import IPython
                         try:
-                            #Attempt to load IPython debugger
-                            import IPython.core.ipapi
                             import IPython.core.debugger
-                            ip = IPython.core.ipapi.get()
-                            debugger = IPython.core.debugger.Pdb(ip.colors)
+                            try:
+                                from IPython.terminal.ipapp import load_default_config
+                                config = load_default_config()
+                                colors = config.TerminalInteractiveShell.colors
+                            except:
+                                import IPython.core.ipapi
+                                ip = IPython.core.ipapi.get()
+                                colors = ip.colors
+                            debugger = IPython.core.debugger.Pdb(colors)
                         except ImportError:
                             #Fallback to older version of IPython API
                             import IPython.ipapi
@@ -239,7 +248,7 @@ def execute(options):
         if after == previous:
             from time import sleep
             noprogress += 1
-            sleep(options.execute_wait_cycle_time_secs)
+            sleep(int(options.execute_wait_cycle_time_secs))
     else:
         logging.info('No tasks can be run!')
 
@@ -372,8 +381,9 @@ def init(jugfile=None, jugdir=None, on_error='exit', store=None):
     jugmodule.__file__ = os.path.abspath(jugfile)
     jugspace = jugmodule.__dict__
     sys.modules[jugmodname] = jugmodule
+    jugfile_contents = open(jugfile).read()
     try:
-        exec(compile(open(jugfile).read(), jugfile, 'exec'), jugspace, jugspace)
+        exec(compile(jugfile_contents, jugfile, 'exec'), jugspace, jugspace)
     except BarrierError:
         jugspace['__jug__hasbarrier__'] = True
     except Exception as e:
@@ -384,6 +394,9 @@ def init(jugfile=None, jugdir=None, on_error='exit', store=None):
             sys.exit(1)
         else:
             raise
+
+    # The store may have been changed by the jugfile.
+    store = Task.store
     return store, jugspace
 
 
